(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     12540,        381]
NotebookOptionsPosition[     11821,        357]
NotebookOutlinePosition[     12278,        374]
CellTagsIndexPosition[     12235,        371]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[{
 RowBox[{
  RowBox[{"Quiet", "@", 
   RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$HistoryLength", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{3.780381571888649*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mm", "=", "0.001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cm", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dchar", "=", 
   RowBox[{"0.1", "mm"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"length", "=", 
   RowBox[{"1", "cm"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Nu]", "=", 
   RowBox[{"16.92", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vmax", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Remax", "=", 
   FractionBox[
    RowBox[{"Dchar", "*", "vmax"}], "\[Nu]"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<maximal Reynolds number= \>\"", ",", "Remax", ",", "\"\< -\>\""}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.78038208560815*^9, 3.780382123126216*^9}, {
  3.7803822395024204`*^9, 3.780382274118881*^9}, {3.7803825591625814`*^9, 
  3.7803826095974703`*^9}, {3.780984256785571*^9, 3.7809842595779757`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Pr", "=", "0.7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Nu", "[", "re_", "]"}], ":=", 
   RowBox[{
    RowBox[{"0.989", "*", 
     SuperscriptBox["re", "0.33"], "*", 
     SuperscriptBox["Pr", 
      FractionBox["1", "3"]]}], "/;", 
    RowBox[{"0.4", "\[LessEqual]", "re", "<", "4"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Nu", "[", "re_", "]"}], ":=", 
   RowBox[{
    RowBox[{"0.911", "*", 
     SuperscriptBox["re", "0.385"], "*", 
     SuperscriptBox["Pr", 
      FractionBox["1", "3"]]}], "/;", 
    RowBox[{"4", "\[LessEqual]", "re", "<", "40"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Nu", "[", "re_", "]"}], ":=", 
   RowBox[{
    RowBox[{"0.683", "*", 
     SuperscriptBox["re", "0.466"], "*", 
     SuperscriptBox["Pr", 
      FractionBox["1", "3"]]}], "/;", 
    RowBox[{"40", "\[LessEqual]", "re", "<", "4000"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogLogPlot", "[", 
  RowBox[{
   RowBox[{"Nu", "[", "re", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"re", ",", "10", ",", "100"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", "0.0006", "]"}], ",", "Red"}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Re\>\"", ",", "\"\<Nu\>\""}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Full"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.780382981706924*^9, 3.780383271695833*^9}, {
  3.7809862953335514`*^9, 3.7809863208863964`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"dataThermalConductivity", "=", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "10"}], ",", "23.59"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "24.36"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "25.12"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", "25.87"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"30", ",", "26.62"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"40", ",", "27.35"}], "}"}]}], "}"}], "/.", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"T_", ",", "\[Lambda]_"}], "}"}], "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{"T", ",", 
        RowBox[{
         SuperscriptBox["10", 
          RowBox[{"-", "3"}]], "*", "\[Lambda]"}]}], "}"}]}]}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"\[Lambda]", "=", 
     RowBox[{"Interpolation", "[", "dataThermalConductivity", "]"}]}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Lambda]", "[", "T_", "]"}], "=", 
   RowBox[{"Fit", "[", 
    RowBox[{"dataThermalConductivity", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "T"}], "}"}], ",", "T"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"\[Lambda]", "[", "T", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"T", ",", 
        RowBox[{"-", "10"}], ",", "40"}], "}"}]}], "]"}], ",", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"dataThermalConductivity", ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
   "]"}], ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.7809836837487645`*^9, 3.78098399996132*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dataKinematicViscosity", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "23"}], ",", "1.132"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1.343"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"27", ",", "1.568"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"52", ",", "1.807"}], "}"}]}], "}"}], "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"T_", ",", "\[Nu]_"}], "}"}], "\[RuleDelayed]", 
     RowBox[{"{", 
      RowBox[{"T", ",", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "5"}]], "*", "\[Nu]"}]}], "}"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ClearAll", "[", "\[Nu]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Nu]", "[", "T_", "]"}], "=", 
   RowBox[{"Fit", "[", 
    RowBox[{"dataKinematicViscosity", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "T", ",", 
       SuperscriptBox["T", "2"]}], "}"}], ",", "T"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"\[Nu]", "[", "T", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"T", ",", 
        RowBox[{"-", "24"}], ",", "54"}], "}"}]}], "]"}], ",", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"dataKinematicViscosity", ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
   "]"}], ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.780984004610128*^9, 3.7809840162477484`*^9}, {
  3.780984107118908*^9, 3.7809842443679495`*^9}, {3.7809842879388256`*^9, 
  3.7809843675613656`*^9}, {3.7809844861059732`*^9, 3.780984497103993*^9}, {
  3.780984600968975*^9, 3.7809846056645837`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Rey", "[", 
    RowBox[{"T_", ",", "velocity_"}], "]"}], ":=", 
   FractionBox[
    RowBox[{"Dchar", "*", "velocity"}], 
    RowBox[{"\[Nu]", "[", "T", "]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", 
    RowBox[{"Ts_", ",", "Ta_", ",", "velocity_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Tdef", ",", "re", ",", "nu", ",", "alpha"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Tdef", "=", 
       FractionBox[
        RowBox[{"Ts", "+", "Ta"}], "2"]}], ";", "\[IndentingNewLine]", 
      RowBox[{"re", "=", 
       RowBox[{"Rey", "[", 
        RowBox[{"Tdef", ",", "velocity"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"nu", "=", 
       RowBox[{"Nu", "[", "re", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"alpha", "=", 
       RowBox[{"nu", "*", 
        FractionBox[
         RowBox[{"\[Lambda]", "[", "Tdef", "]"}], "Dchar"]}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[Alpha]", "[", 
  RowBox[{"30", ",", "10", ",", "1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7809846173490043`*^9, 3.7809849173687315`*^9}, {
  3.7809849757908335`*^9, 3.780984980361642*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"S", "=", 
   RowBox[{"length", "*", "Pi", "*", "Dchar"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"powerConvection", "[", 
    RowBox[{"Ts_", ",", "Ta_", ",", "velocity_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"Ts", ",", "Ta", ",", "velocity"}], "]"}], "*", "S", "*", 
    RowBox[{"(", 
     RowBox[{"Ts", "-", "Ta"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"powerConvection", "[", 
  RowBox[{"30", ",", "10", ",", "1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.780984990018059*^9, 3.7809851037110586`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Epsilon]", "=", "0.9"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]", "=", 
   RowBox[{"5.67", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "8"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"powerRadiation", "[", 
    RowBox[{"Ts_", ",", "Ta_"}], "]"}], ":=", 
   RowBox[{"S", "*", "\[Epsilon]", "*", "\[Sigma]", "*", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Ts", "+", "273"}], ")"}], "4"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Ta", "+", "273"}], ")"}], "4"]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"powerRadiation", "[", 
  RowBox[{"30", ",", "10"}], "]"}]}], "Input",
 CellChangeTimes->{{3.780985122852292*^9, 3.7809851509323416`*^9}, {
  3.7809851969992228`*^9, 3.7809852487777133`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"powerConvection", "[", 
   RowBox[{"30", ",", "10", ",", "1"}], "]"}], 
  RowBox[{"powerRadiation", "[", 
   RowBox[{"30", ",", "10"}], "]"}]]], "Input",
 CellChangeTimes->{{3.78098526974415*^9, 3.7809852750793595`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TWire", "=", "40"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Pel", "[", 
    RowBox[{"Ta_", ",", "velocity_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"powerRadiation", "[", 
     RowBox[{"TWire", ",", "Ta"}], "]"}], "+", 
    RowBox[{"powerConvection", "[", 
     RowBox[{"TWire", ",", "Ta", ",", "velocity"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ta", "=", "20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Pel", "[", 
     RowBox[{"Ta", ",", "velocity"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"velocity", ",", "0.5", ",", "10"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Pel", "[", 
      RowBox[{"Ta", ",", "velocity"}], "]"}], ",", "velocity"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"velocity", ",", "0.5", ",", "10"}], "}"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Pel [W]\>\"", ",", "\"\<velocity [m/s]\>\""}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.780985928842108*^9, 3.780986031412288*^9}, {
  3.7809860639695454`*^9, 3.7809862156174116`*^9}}]
},
WindowSize->{1113, 778},
WindowMargins->{{24, Automatic}, {Automatic, 30}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
Magnification->2.200000047683716,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 398, 11, 193, "Input"],
Cell[958, 33, 1043, 28, 403, "Input"],
Cell[2004, 63, 1592, 47, 402, "Input"],
Cell[3599, 112, 1917, 58, 435, "Input"],
Cell[5519, 172, 1873, 54, 439, "Input"],
Cell[7395, 228, 1306, 35, 597, "Input"],
Cell[8704, 265, 616, 16, 221, "Input"],
Cell[9323, 283, 874, 25, 268, "Input"],
Cell[10200, 310, 259, 6, 136, "Input"],
Cell[10462, 318, 1355, 37, 473, "Input"]
}
]
*)

(* End of internal cache information *)
