(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      5016,        152]
NotebookOptionsPosition[      4509,        132]
NotebookOutlinePosition[      4966,        149]
CellTagsIndexPosition[      4923,        146]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[{
 RowBox[{
  RowBox[{"Quiet", "@", 
   RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$HistoryLength", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{3.7809869180242453`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"VolumeFlow", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nYears", "=", "15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"price", "[", "kS_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox["10", "4"], "+", 
    RowBox[{
     SuperscriptBox["10", "3"], "*", "kS"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cp", "=", "1025"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Tin", "=", "20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Tout", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"price1GJ", "=", "700"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"heatingTime", "=", 
   RowBox[{"200", "*", "24", "*", "3600", "*", "nYears"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"density", "=", 
   FractionBox["349.", 
    RowBox[{"Tin", "+", "273"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"massFlow", "=", 
   RowBox[{"VolumeFlow", "*", "density"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"temperatures", "[", "kS_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "eqns", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"eqns", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"massFlow", "*", "cp", "*", 
           RowBox[{"(", 
            RowBox[{"Tin", "+", "Tout"}], ")"}]}], "==", 
          RowBox[{"massFlow", "*", "cp", "*", 
           RowBox[{"(", 
            RowBox[{"T2", "+", "T3"}], ")"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"P", "==", 
          RowBox[{"massFlow", "*", "cp", "*", 
           RowBox[{"(", 
            RowBox[{"T3", "-", "Tout"}], ")"}]}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"P", "\[Equal]", 
          RowBox[{"kS", "*", 
           RowBox[{"(", 
            RowBox[{"Tin", "-", "T3"}], ")"}]}]}]}], "\[IndentingNewLine]", 
        "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"T2", ",", "T3", ",", "P"}], "}"}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{"eqns", ",", 
          RowBox[{"{", 
           RowBox[{"T2", ",", "T3", ",", "P"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"powerThrioughExchanger", "[", "kS_", "]"}], "=", 
   RowBox[{
    RowBox[{"temperatures", "[", "kS", "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"-", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.780986921191051*^9, 3.780987043651266*^9}, {
   3.780987103336971*^9, 3.7809871067689767`*^9}, {3.780987158155467*^9, 
   3.7809871884507203`*^9}, {3.7809873564952154`*^9, 
   3.7809874194101257`*^9}, {3.780987452606984*^9, 3.780987533368326*^9}, {
   3.780987601961647*^9, 3.7809878820601387`*^9}, 3.780987937861437*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"savedEnergyinGJ", "[", "kS_", "]"}], ":=", 
   RowBox[{
    RowBox[{"powerThrioughExchanger", "[", "kS", "]"}], "*", 
    FractionBox["heatingTime", 
     SuperscriptBox["10", "9"]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"savedEnergyinGJ", "[", "100", "]"}]}], "Input",
 CellChangeTimes->{{3.780988020588382*^9, 3.7809880632700567`*^9}, {
  3.7809882123907185`*^9, 3.780988248863583*^9}}],

Cell[BoxData["213.7361865611433`"], "Output",
 CellChangeTimes->{{3.780988245088376*^9, 3.780988249081983*^9}}]
}, Open  ]]
},
WindowSize->{1113, 778},
WindowMargins->{{24, Automatic}, {Automatic, 30}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
Magnification->2.000000238418579,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 374, 10, 137, "Input"],
Cell[934, 32, 2978, 80, 842, "Input"],
Cell[CellGroupData[{
Cell[3937, 116, 442, 10, 199, "Input"],
Cell[4382, 128, 111, 1, 117, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
